==> jettable1.0.0.zip: jettable/sample/client_yfinance.php <==
<?php
require_once "../TableUtility.php";

$list = array();

$list[] = array(""=>"1", ""=>"7203", "Ծ"=>"1", "̾"=>"ȥ西ư()", ""=>"11/17<br>15:00", ""=>"7,260", "ȯԺѳ"=>"3,609,997,492", "<br>ɴߡ"=>"26,208,582", "ñ"=>"100", "Ϣ"=>"㡼 Ⱦ Ǽ ˥塼 ݡ");
$list[] = array(""=>"2", ""=>"8306", "Ծ"=>"1", "̾"=>"()ɩգƣʥեʥ󥷥롦롼", ""=>"11/17<br>15:00", ""=>"1,420,000", "ȯԺѳ"=>"10,761,770", "<br>ɴߡ"=>"15,281,713", "ñ"=>"-", "Ϣ"=>"㡼 Ⱦ Ǽ ˥塼 ݡ");
$list[] = array(""=>"3", ""=>"8411", "Ծ"=>"1", "̾"=>"()ߤۥեʥ󥷥륰롼", ""=>"11/17<br>15:00", ""=>"849,000", "ȯԺѳ"=>"11,872,195", "<br>ɴߡ"=>"10,079,494", "ñ"=>"-", "Ϣ"=>"㡼 Ⱦ Ǽ ˥塼 ݡ");
$list[] = array(""=>"4", ""=>"8316", "Ծ"=>"1", "̾"=>"()潻ͧեʥ󥷥륰롼", ""=>"11/17<br>15:00", ""=>"1,200,000", "ȯԺѳ"=>"7,733,653", "<br>ɴߡ"=>"9,280,384", "ñ"=>"-", "Ϣ"=>"㡼 Ⱦ Ǽ ˥塼 ݡ");
$list[] = array(""=>"5", ""=>"9432", "Ծ"=>"1", "̾"=>"ſ()", ""=>"11/17<br>15:00", ""=>"573,000", "ȯԺѳ"=>"15,741,209", "<br>ɴߡ"=>"9,019,713", "ñ"=>"-", "Ϣ"=>"㡼 Ⱦ Ǽ ˥塼 ݡ");
$list[] = array(""=>"6", ""=>"9437", "Ծ"=>"1", "̾"=>"()Σԣԥɥ", ""=>"11/17<br>15:00", ""=>"182,000", "ȯԺѳ"=>"46,810,000", "<br>ɴߡ"=>"8,519,420", "ñ"=>"-", "Ϣ"=>"㡼 Ⱦ Ǽ ˥塼 ݡ");
$list[] = array(""=>"7", ""=>"7751", "Ծ"=>"1", "̾"=>"Υ()", ""=>"11/17<br>15:00", ""=>"6,310", "ȯԺѳ"=>"1,333,359,658", "<br>ɴߡ"=>"8,413,499", "ñ"=>"100", "Ϣ"=>"㡼 Ⱦ Ǽ ˥塼 ݡ");
$list[] = array(""=>"8", ""=>"7267", "Ծ"=>"1", "̾"=>"ۥ", ""=>"11/17<br>15:00", ""=>"4,210", "ȯԺѳ"=>"1,834,828,430", "<br>ɴߡ"=>"7,724,628", "ñ"=>"100", "Ϣ"=>"㡼 Ⱦ Ǽ ˥塼 ݡ ͥ");  
$list[] = array(""=>"9", ""=>"4502", "Ծ"=>"1", "̾"=>"ʹ()", ""=>"11/17<br>15:00", ""=>"7,500", "ȯԺѳ"=>"889,272,395", "<br>ɴߡ"=>"6,669,543", "ñ"=>"100", "Ϣ"=>"㡼 Ⱦ Ǽ ˥塼 ݡ");
$list[] = array(""=>"10", ""=>"7201", "Ծ"=>"1", "̾"=>"ư()", ""=>"11/17<br>15:00", ""=>"1,440", "ȯԺѳ"=>"4,520,715,112", "<br>ɴߡ"=>"6,509,830", "ñ"=>"100", "Ϣ"=>"㡼 Ⱦ Ǽ ˥塼 ݡ");


$table = new Table();
$table->setData($list);
/*
$table->setHeader(array(
	"sign"=>"᥽åɤγ", 
	"summary"=>"", 
));
*/
$table->appendAttribute("border", "0");
$table->appendAttribute("cellpadding", "5");
$table->appendAttribute("cellspacing", "0");
$table->appendAttribute("width", "100%");
$table->appendAttribute("style", "border-collapse:collapse;border:1px solid #ccc;");

$table->margeHeaderColumn("", 2);

$table->appendAttributeHeaderColumnAll("style", "border:1px solid #ccc;");
$table->appendAttributeHeaderColumnAll("noWrap", "noWrap");

$table->appendAttributeHeaderRow("bgcolor", "#eeeedd");
$table->appendAttributeHeaderRow("style", "font-size:80%;border:1px solid #ccc;");
$table->appendAttributeHeaderColumn("<br>ɴߡ", "bgcolor", "#cccc66");

$table->appendAttributeColumnAll("style", "border:1px solid #ccc;");

$table->appendAttributeColumn("", "bgcolor", "#ffffee");
$table->appendAttributeColumn("", "align", "middle");
$table->appendAttributeColumn("", "align", "right");
$table->appendAttributeColumn("ȯԺѳ", "align", "right");
$table->appendAttributeColumn("ñ", "align", "right");
$table->appendAttributeColumn("<br>ɴߡ", "align", "right");
$table->appendAttributeColumn("<br>ɴߡ", "bgcolor", "#ffffcc");
$table->appendAttributeColumn("", "style", "cursor:hand;color:#00f;text-decoration:underline;text-align:center;");
$table->appendAttributeColumn("Ϣ", "style", "cursor:hand;color:#00f;text-decoration:underline;font-size:80%;");

print<<<HEADER
<html>
<head>
<style type="text/css">
<!--
-->
</style>
</head>
<body>
HEADER;

print $table->getTableHtml();

print<<<FOOTER
</body>
</html>
FOOTER;
?>

==> jettable2.0.0.zip: jettable/sample/client_yfinance.php <==
<?php
require_once "../JetTable.php";

$list = array();

$list[] = array(""=>"1", ""=>"7203", "Ծ"=>"1", "̾"=>"ȥ西ư()", ""=>"11/17<br>15:00", ""=>"7,260", "ȯԺѳ"=>"3,609,997,492", "<br>ɴߡ"=>"26,208,582", "ñ"=>"100", "Ϣ"=>"㡼 Ⱦ Ǽ ˥塼 ݡ");
$list[] = array(""=>"2", ""=>"8306", "Ծ"=>"1", "̾"=>"()ɩգƣʥեʥ󥷥롦롼", ""=>"11/17<br>15:00", ""=>"1,420,000", "ȯԺѳ"=>"10,761,770", "<br>ɴߡ"=>"15,281,713", "ñ"=>"-", "Ϣ"=>"㡼 Ⱦ Ǽ ˥塼 ݡ");
$list[] = array(""=>"3", ""=>"8411", "Ծ"=>"1", "̾"=>"()ߤۥեʥ󥷥륰롼", ""=>"11/17<br>15:00", ""=>"849,000", "ȯԺѳ"=>"11,872,195", "<br>ɴߡ"=>"10,079,494", "ñ"=>"-", "Ϣ"=>"㡼 Ⱦ Ǽ ˥塼 ݡ");
$list[] = array(""=>"4", ""=>"8316", "Ծ"=>"1", "̾"=>"()潻ͧեʥ󥷥륰롼", ""=>"11/17<br>15:00", ""=>"1,200,000", "ȯԺѳ"=>"7,733,653", "<br>ɴߡ"=>"9,280,384", "ñ"=>"-", "Ϣ"=>"㡼 Ⱦ Ǽ ˥塼 ݡ");
$list[] = array(""=>"5", ""=>"9432", "Ծ"=>"1", "̾"=>"ſ()", ""=>"11/17<br>15:00", ""=>"573,000", "ȯԺѳ"=>"15,741,209", "<br>ɴߡ"=>"9,019,713", "ñ"=>"-", "Ϣ"=>"㡼 Ⱦ Ǽ ˥塼 ݡ");
$list[] = array(""=>"6", ""=>"9437", "Ծ"=>"1", "̾"=>"()Σԣԥɥ", ""=>"11/17<br>15:00", ""=>"182,000", "ȯԺѳ"=>"46,810,000", "<br>ɴߡ"=>"8,519,420", "ñ"=>"-", "Ϣ"=>"㡼 Ⱦ Ǽ ˥塼 ݡ");
$list[] = array(""=>"7", ""=>"7751", "Ծ"=>"1", "̾"=>"Υ()", ""=>"11/17<br>15:00", ""=>"6,310", "ȯԺѳ"=>"1,333,359,658", "<br>ɴߡ"=>"8,413,499", "ñ"=>"100", "Ϣ"=>"㡼 Ⱦ Ǽ ˥塼 ݡ");
$list[] = array(""=>"8", ""=>"7267", "Ծ"=>"1", "̾"=>"ۥ", ""=>"11/17<br>15:00", ""=>"4,210", "ȯԺѳ"=>"1,834,828,430", "<br>ɴߡ"=>"7,724,628", "ñ"=>"100", "Ϣ"=>"㡼 Ⱦ Ǽ ˥塼 ݡ ͥ");  
$list[] = array(""=>"9", ""=>"4502", "Ծ"=>"1", "̾"=>"ʹ()", ""=>"11/17<br>15:00", ""=>"7,500", "ȯԺѳ"=>"889,272,395", "<br>ɴߡ"=>"6,669,543", "ñ"=>"100", "Ϣ"=>"㡼 Ⱦ Ǽ ˥塼 ݡ");
$list[] = array(""=>"10", ""=>"7201", "Ծ"=>"1", "̾"=>"ư()", ""=>"11/17<br>15:00", ""=>"1,440", "ȯԺѳ"=>"4,520,715,112", "<br>ɴߡ"=>"6,509,830", "ñ"=>"100", "Ϣ"=>"㡼 Ⱦ Ǽ ˥塼 ݡ");


$table = new JetTable();
$table->setData($list);
/*
$table->setHeader(array(
	"sign"=>"᥽åɤγ", 
	"summary"=>"", 
));
*/
$table->appendAttribute("border", "0");
$table->appendAttribute("cellpadding", "5");
$table->appendAttribute("cellspacing", "0");
$table->appendAttribute("width", "100%");
$table->appendAttribute("style", "border-collapse:collapse;border:1px solid #ccc;");

$table->margeHeaderColumn("", 2);

$table->appendAttributeHeaderColumnAll("style", "border:1px solid #ccc;");
$table->appendAttributeHeaderColumnAll("noWrap", "noWrap");

$table->appendAttributeHeaderRow("bgcolor", "#eeeedd");
$table->appendAttributeHeaderRow("style", "font-size:80%;border:1px solid #ccc;");
$table->appendAttributeHeaderColumn("<br>ɴߡ", "bgcolor", "#cccc66");

$table->appendAttributeColumnAll("style", "border:1px solid #ccc;");

$table->appendAttributeColumn("", "bgcolor", "#ffffee");
$table->appendAttributeColumn("", "align", "middle");
$table->appendAttributeColumn("", "align", "right");
$table->appendAttributeColumn("ȯԺѳ", "align", "right");
$table->appendAttributeColumn("ñ", "align", "right");
$table->appendAttributeColumn("<br>ɴߡ", "align", "right");
$table->appendAttributeColumn("<br>ɴߡ", "bgcolor", "#ffffcc");
$table->appendAttributeColumn("", "style", "cursor:hand;color:#00f;text-decoration:underline;text-align:center;");
$table->appendAttributeColumn("Ϣ", "style", "cursor:hand;color:#00f;text-decoration:underline;font-size:80%;");

print<<<HEADER
<html>
<head>
<style type="text/css">
<!--
-->
</style>
</head>
<body>
HEADER;

print $table->getTableHtml();

print<<<FOOTER
</body>
</html>
FOOTER;
?>
